@@ -9,7 +9,7 @@ ip_file = '/tmp/.current_external_ip'
 
 #################################
 # API
-def update_ddns_server(update_url, verbose=False, update=False):
+def update_ddns_server(update_url, verbose=False, update=True):
     external_ip = get_external_ip()
     if verbose:
         log.basicConfig(level=log.DEBUG)
